@@ -71,11 +71,25 @@ def get_wgpu_lib_path():
     # Note that this can be a false positive, e.g. ARM linux.
     embedded_path = get_resource_filename(lib_filename)
     if not os.path.isfile(embedded_path):  # no-cover
-        raise RuntimeError(f"Could not find WGPU library in {embedded_path}")
+        raise RuntimeError(
+            f"Could not find WGPU library in {embedded_path}. {_maybe_get_hint_on_download_script()}"
+        )
     else:
         return embedded_path
 
 
+def _maybe_get_hint_on_download_script():
+    root_dir = os.path.join(get_resource_filename(""), "..", "..")
+    filename = os.path.abspath(os.path.join(root_dir, "download-wgpu-native.py"))
+    uses_repo = os.path.isfile(filename)
+
+    uses_custom_lib = os.getenv("WGPU_LIB_PATH", "").strip()
+
+    if uses_repo and not uses_custom_lib:
+        return "You may need to run download-wgpu-native.py (in the root of the repo)."
+    return ""
+
+
 # Configure cffi and load the dynamic library
 # NOTE: `import wgpu.backends.rs` is used in pyinstaller tests to verify
 # that we can load the DLL after freezing
@@ -100,7 +114,7 @@ def check_expected_version(version_info):
     # Compare
     if version_info_lib != version_info:  # no-cover
         logger.warning(
-            f"Expected wgpu-native version {version_info} but got {version_info_lib}"
+            f"Expected wgpu-native version {version_info} but got {version_info_lib}. {_maybe_get_hint_on_download_script()}"
         )
 
 
